#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: aeson-compat
version: 0.3.2.0
id: aeson-compat-0.3.2.0-725b78f3168d9bafe282f8360603746a
key: aeson_BKOlp5ASGYD15xjKUB8zTq
license: BSD3
maintainer: Oleg Grenrus <oleg.grenrus@iki.fi>
homepage: https://github.com/phadej/aeson-compat#readme
synopsis: Compatibility layer for aeson
description:
    Compatibility layer for @aeson@
category: Web
author: Oleg Grenrus <oleg.grenrus@iki.fi>
exposed: True
exposed-modules:
    Data.Aeson.Compat
hidden-modules: Data.Aeson.Compat.Time
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/aeson-compat-0.3.2.0
library-dirs: /usr/lib/ghc-7.10.3/site-local/aeson-compat-0.3.2.0
data-dir: /usr/share/arm-linux-ghc-7.10.3/aeson-compat-0.3.2.0
hs-libraries: HSaeson-compat-0.3.2.0-BKOlp5ASGYD15xjKUB8zTq
depends:
    aeson-0.11.1.4-4ad27f2347131dcc86b1af72cd00fe7c
    attoparsec-0.13.0.1-522c252ad233781393fab28c8daf023a
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    base-compat-0.9.0-fa16321d7131a0167d57b06b47b516c7
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    exceptions-0.8.2.1-8c1fe53cd5846ab1f6d4c58870c4f8d9
    hashable-1.2.4.0-165ac1864c8f5bd906b25f6a12db4f18
    scientific-0.3.4.6-7ee193f22b0f4a7e2e484deeaee5cd03
    semigroups-0.18.1-30b269dfd15f1b13a72c07aebe8ef1de
    tagged-0.8.3-aa128de4449752177a05765fb0ce3959
    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
    time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
    time-locale-compat-0.1.1.1-4bbdeebce90c671369911a4d16cfee44
    unordered-containers-0.2.7.0-d91279dcd5fa13d7f88095dc08e2fda6
    vector-0.11.0.0-711d35c4a6ac1ea2e529dc3ee3328963
haddock-interfaces: /usr/share/doc/haskell-aeson-compat/html/aeson-compat.haddock
haddock-html: /usr/share/doc/haskell-aeson-compat/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
